import toast from '@/modules/toast';

export default {
    methods: {
        clearErrors: function () {
            for (let param in this.fieldErrors) {
                this.fieldErrors[param] = null;
            }
        },
        showErrors: function (e) {
            if (e && e.data && typeof e.data !== 'undefined') {
                if (typeof e.data.reason === 'string' && e.data.reason !== '') {
                    toast('error', e.data.reason);
                } else if (e.status === 504) {
                    console.warn('504 Gateway Timeout');
                    toast('error', '504 Gateway Timeout');
                }
                if(Array.isArray(e.data.errors)) {
                    let errs = {};
                    e.data.errors.forEach((item, index) => {
                        errs[index] = item;
                    });
                    e.data.errors = errs;
                }

                if (typeof e.data.errors === 'object') {
                    let fieldErrors = e.data.errors;
                    let notFieldErrors = [];
                    let errors = {};
                    for (let param in fieldErrors) {
                        if (fieldErrors.hasOwnProperty(param)) {
                            if (typeof this.fieldErrors[param] !== 'undefined') {
                                if (typeof fieldErrors[param]['code'] !== 'undefined' && typeof fieldErrors[param]['reason'] !== 'undefined') {
                                    errors[param] = fieldErrors[param];
                                } else {
                                    // support multi level errors
                                    for (let param2 in this.fieldErrors[param]) {
                                        if (typeof errors[param] === 'undefined') {
                                            errors[param] = {};
                                        }
                                        errors[param][param2] = (fieldErrors[param] && fieldErrors[param][param2]) ? fieldErrors[param][param2] : null;
                                    }
                                }
                            } else {
                                notFieldErrors.push(fieldErrors[param].reason);
                            }
                        }
                    }
                    Object.assign(this.fieldErrors, errors);
                    if (notFieldErrors.length) {
                        toast('error', notFieldErrors.concat('<br />'));
                    }
                }
            }
        },
        getErrorReason: function(data) {
            return (data && data.reason !== 'undefined') ? data.reason : null;
        }
    }
};
